svn commit: samba r15943 - branches/SAMBA_3_0/source/locking branches/SAMBA_3_0/source/smbd trunk/source/locking trunk/source/smbd

jpeach at samba.org jpeach at samba.org
Mon May 29 23:54:56 GMT 2006


Author: jpeach
Date: 2006-05-29 23:54:53 +0000 (Mon, 29 May 2006)
New Revision: 15943

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=15943

Log:
Update misleading DEBUG statements and comments that refer to
open_file_shared.

Modified:
   branches/SAMBA_3_0/source/locking/locking.c
   branches/SAMBA_3_0/source/smbd/nttrans.c
   branches/SAMBA_3_0/source/smbd/open.c
   trunk/source/locking/locking.c
   trunk/source/smbd/nttrans.c
   trunk/source/smbd/open.c


Changeset:
Modified: branches/SAMBA_3_0/source/locking/locking.c
===================================================================
--- branches/SAMBA_3_0/source/locking/locking.c	2006-05-29 23:46:43 UTC (rev 15942)
+++ branches/SAMBA_3_0/source/locking/locking.c	2006-05-29 23:54:53 UTC (rev 15943)
@@ -1116,7 +1116,7 @@
 /****************************************************************************
  Deal with the internal needs of setting the delete on close flag. Note that
  as the tdb locking is recursive, it is safe to call this from within 
- open_file_shared. JRA.
+ open_file_ntcreate. JRA.
 ****************************************************************************/
 
 NTSTATUS can_set_delete_on_close(files_struct *fsp, BOOL delete_on_close,

Modified: branches/SAMBA_3_0/source/smbd/nttrans.c
===================================================================
--- branches/SAMBA_3_0/source/smbd/nttrans.c	2006-05-29 23:46:43 UTC (rev 15942)
+++ branches/SAMBA_3_0/source/smbd/nttrans.c	2006-05-29 23:54:53 UTC (rev 15943)
@@ -1704,8 +1704,9 @@
 
 	close_ret = close_file(fsp2,NORMAL_CLOSE);
 
-	/* Grrr. We have to do this as open_file_shared1 adds aARCH when it
-	   creates the file. This isn't the correct thing to do in the copy case. JRA */
+	/* Grrr. We have to do this as open_file_ntcreate adds aARCH when it
+	   creates the file. This isn't the correct thing to do in the copy
+	   case. JRA */
 	file_set_dosmode(conn, newname, fattr, &sbuf2, True);
 
 	if (ret < (SMB_OFF_T)sbuf1.st_size) {

Modified: branches/SAMBA_3_0/source/smbd/open.c
===================================================================
--- trunk/source/locking/locking.c	2006-05-29 23:46:43 UTC (rev 15942)
+++ trunk/source/locking/locking.c	2006-05-29 23:54:53 UTC (rev 15943)
@@ -1116,7 +1116,7 @@
 /****************************************************************************
  Deal with the internal needs of setting the delete on close flag. Note that
  as the tdb locking is recursive, it is safe to call this from within 
- open_file_shared. JRA.
+ open_file_ntcreate. JRA.
 ****************************************************************************/
 
 NTSTATUS can_set_delete_on_close(files_struct *fsp, BOOL delete_on_close,

Modified: trunk/source/smbd/nttrans.c
===================================================================
--- trunk/source/smbd/nttrans.c	2006-05-29 23:46:43 UTC (rev 15942)
+++ trunk/source/smbd/nttrans.c	2006-05-29 23:54:53 UTC (rev 15943)
@@ -1700,8 +1700,9 @@
 
 	close_ret = close_file(fsp2,NORMAL_CLOSE);
 
-	/* Grrr. We have to do this as open_file_shared1 adds aARCH when it
-	   creates the file. This isn't the correct thing to do in the copy case. JRA */
+	/* Grrr. We have to do this as open_file_ntcreate adds aARCH when it
+	   creates the file. This isn't the correct thing to do in the copy
+	   case. JRA */
 	file_set_dosmode(conn, newname, fattr, &sbuf2, True);
 
 	if (ret < (SMB_OFF_T)sbuf1.st_size) {

Modified: trunk/source/smbd/open.c
===================================================================
--- branches/SAMBA_3_0/source/smbd/open.c	2006-05-29 23:46:43 UTC (rev 15942)
+++ branches/SAMBA_3_0/source/smbd/open.c	2006-05-29 23:54:53 UTC (rev 15943)
@@ -245,7 +245,7 @@
 
 		/*
 		 * We can't actually truncate here as the file may be locked.
 		 * open_file_shared will take care of the truncate later. JRA.
 		 */
 
 		local_flags &= ~O_TRUNC;
@@ -1742,7 +1742,7 @@
 			if (ret == -1 && errno == ENOSYS) {
 				errno = saved_errno; /* Ignore ENOSYS */
 			} else {
-				DEBUG(5, ("open_file_shared: reset "
+				DEBUG(5, ("open_file_ntcreate: reset "
 					  "attributes of file %s to 0%o\n",
 					fname, (unsigned int)new_unx_mode));
 				ret = 0; /* Don't do the fchmod below. */
@@ -1751,7 +1751,7 @@
 
 		if ((ret == -1) &&
 		    (SMB_VFS_FCHMOD(fsp, fsp->fh->fd, new_unx_mode) == -1))
-			DEBUG(5, ("open_file_shared: failed to reset "
+			DEBUG(5, ("open_file_ntcreate: failed to reset "
 				  "attributes of file %s to 0%o\n",
 				fname, (unsigned int)new_unx_mode));
 	}
@@ -245,7 +245,7 @@
 		/*
 		 * We can't actually truncate here as the file may be locked.
-		 * open_file_shared will take care of the truncate later. JRA.
+		 * open_file_ntcreate will take care of the truncate later. JRA.
 		 */
 

Modified: trunk/source/locking/locking.c
===================================================================
--- trunk/source/smbd/open.c	2006-05-29 23:46:43 UTC (rev 15942)
+++ trunk/source/smbd/open.c	2006-05-29 23:54:53 UTC (rev 15943)
@@ -245,7 +245,7 @@
 
 		/*
 		 * We can't actually truncate here as the file may be locked.
 		 * open_file_shared will take care of the truncate later. JRA.
 		 */
 
 		local_flags &= ~O_TRUNC;
@@ -1738,7 +1738,7 @@
 			if (ret == -1 && errno == ENOSYS) {
 				errno = saved_errno; /* Ignore ENOSYS */
 			} else {
-				DEBUG(5, ("open_file_shared: reset "
+				DEBUG(5, ("open_file_ntcreate: reset "
 					  "attributes of file %s to 0%o\n",
 					fname, (unsigned int)new_unx_mode));
 				ret = 0; /* Don't do the fchmod below. */
@@ -1747,7 +1747,7 @@
 
 		if ((ret == -1) &&
 		    (SMB_VFS_FCHMOD(fsp, fsp->fh->fd, new_unx_mode) == -1))
-			DEBUG(5, ("open_file_shared: failed to reset "
+			DEBUG(5, ("open_file_ntcreate: failed to reset "
 				  "attributes of file %s to 0%o\n",
 				fname, (unsigned int)new_unx_mode));
 	}
@@ -245,7 +245,7 @@
 		/*
 		 * We can't actually truncate here as the file may be locked.
-		 * open_file_shared will take care of the truncate later. JRA.
+		 * open_file_ntcreate will take care of the truncate later. JRA.
 		 */
 



More information about the samba-cvs mailing list